@@ -17,14 +17,14 @@ class KinesisFirehoseKinesisRecordMetadata(typing.TypedDict):
 
     sequenceNumber: str
 
-    subsequenceNumber: int
+    subsequenceNumber: str
     """
 
     shardId: str
     partitionKey: str
     approximateArrivalTimestamp: str
     sequenceNumber: str
-    subsequenceNumber: int
+    subsequenceNumber: str
 
 
 class KinesisFirehoseRecord(typing.TypedDict):
@@ -39,7 +39,7 @@ class KinesisFirehoseRecord(typing.TypedDict):
 
     approximateArrivalTimestamp: int
 
-    kinesisRecordMetadata: :class:`KinesisFirehoseKinesisRecordMetadata`
+    kinesisRecordMetadata: :py:class:`KinesisFirehoseKinesisRecordMetadata`
     """
 
     data: str
@@ -60,7 +60,7 @@ class KinesisFirehoseEvent(typing.TypedDict):
 
     region: str
 
-    records: typing.List[:class:`KinesisFirehoseRecord`]
+    records: typing.List[:py:class:`KinesisFirehoseRecord`]
     """
 
     invocationId: str
